@@ -37,8 +37,6 @@ class Model(_Base):
         orphaned_doors: A list of the Door objects in the model that lack
             a parent Face. Note that orphaned Doors are not acceptable for
             Models that are to be exported for energy simulation.
-        north_angle: An number between 0 and 360 to set the clockwise north
-            direction in degrees. Default is 0.
         units: Text for the units system in which the model geometry
             exists. Default: 'Meters'. Choose from the following:
 
@@ -59,8 +57,6 @@ class Model(_Base):
     Properties:
         * identifier
         * display_name
-        * north_angle
-        * north_vector
         * units
         * tolerance
         * angle_tolerance
@@ -76,18 +72,16 @@ class Model(_Base):
         * user_data
     """
     __slots__ = ('_rooms', '_orphaned_faces', '_orphaned_shades', '_orphaned_apertures',
-                 '_orphaned_doors', '_north_angle', '_north_vector', '_units',
-                 '_tolerance', '_angle_tolerance')
+                 '_orphaned_doors', '_units', '_tolerance', '_angle_tolerance')
 
     UNITS = ('Meters', 'Millimeters', 'Feet', 'Inches', 'Centimeters')
 
     def __init__(self, identifier, rooms=None, orphaned_faces=None, orphaned_shades=None,
-                 orphaned_apertures=None, orphaned_doors=None, north_angle=0,
+                 orphaned_apertures=None, orphaned_doors=None,
                  units='Meters', tolerance=0, angle_tolerance=0):
         """A collection of Rooms, Faces, Apertures, and Doors for an entire model."""
         _Base.__init__(self, identifier)  # process the identifier
 
-        self.north_angle = north_angle
         self.units = units
         self.tolerance = tolerance
         self.angle_tolerance = angle_tolerance
@@ -148,14 +142,12 @@ class Model(_Base):
         if 'orphaned_doors' in data and data['orphaned_doors'] is not None:
             orphaned_doors = [Door.from_dict(d) for d in data['orphaned_doors']]
 
-        # import the north angle
-        north_angle = 0 if 'north_angle' not in data else data['north_angle']
+        # import the units
         units = 'Meters' if 'units' not in data else data['units']
 
         # build the model object
         model = Model(data['identifier'], rooms, orphaned_faces, orphaned_shades,
-                      orphaned_apertures, orphaned_doors, north_angle,
-                      units, tol, angle_tol)
+                      orphaned_apertures, orphaned_doors, units, tol, angle_tol)
         if 'display_name' in data and data['display_name'] is not None:
             model.display_name = data['display_name']
         if 'user_data' in data and data['user_data'] is not None:
@@ -166,16 +158,14 @@ class Model(_Base):
         return model
 
     @classmethod
-    def from_objects(cls, identifier, objects, north_angle=0, units='Meters',
-                     tolerance=0, angle_tolerance=0):
+    def from_objects(cls, identifier, objects, units='Meters', tolerance=0,
+                     angle_tolerance=0):
         """Initialize a Model from a list of any type of honeybee-core geometry objects.
 
         Args:
             identifier: Text string for a unique Model ID. Must be < 100 characters and
                 not contain any spaces or special characters.
             objects: A list of honeybee Rooms, Faces, Shades, Apertures and Doors.
-            north_angle: An number between 0 and 360 to set the clockwise north
-                direction in degrees. Default is 0.
             units: Text for the units system in which the model geometry
                 exists. Default: 'Meters'. Choose from the following:
 
@@ -213,30 +203,8 @@ class Model(_Base):
                 raise TypeError('Expected Room, Face, Shade, Aperture or Door '
                                 'for Model. Got {}'.format(type(obj)))
 
-        return cls(identifier, rooms, faces, shades, apertures, doors, north_angle)
-
-    @property
-    def north_angle(self):
-        """Get or set a number between 0 and 360 for the north direction in degrees."""
-        return self._north_angle
-
-    @north_angle.setter
-    def north_angle(self, value):
-        self._north_angle = float_in_range(value, 0.0, 360.0, 'model north angle')
-        self._north_vector = Vector2D(0, 1).rotate(math.radians(-self._north_angle))
-
-    @property
-    def north_vector(self):
-        """Get or set a ladybug_geometry Vector2D for the north direction."""
-        return self._north_vector
-
-    @north_vector.setter
-    def north_vector(self, value):
-        assert isinstance(value, Vector2D), \
-            'Expected Vector2D for north_vector. Got {}.'.format(type(value))
-        self._north_vector = value
-        self._north_angle = \
-            math.degrees(Vector2D(0, 1).angle_clockwise(self._north_vector))
+        return cls(identifier, rooms, faces, shades, apertures, doors, units,
+                   tolerance, angle_tolerance)
 
     @property
     def units(self):
@@ -541,10 +509,6 @@ class Model(_Base):
     def rotate(self, axis, angle, origin):
         """Rotate this Model by a certain angle around an axis and origin.
 
-        Note that using this method does NOT rotate the model north_vector and,
-        if it is desired that this north_vector be rotated with the model geometry,
-        it must be rotated separately.
-
         Args:
             axis: A ladybug_geometry Vector3D axis representing the axis of rotation.
             angle: An angle for rotation in degrees.
@@ -566,10 +530,6 @@ class Model(_Base):
     def rotate_xy(self, angle, origin):
         """Rotate this Model counterclockwise in the world XY plane by a certain angle.
 
-        Note that using this method does NOT rotate the model north_vector and,
-        if it is desired that this north_vector be rotated with the model geometry,
-        it must be rotated separately.
-
         Args:
             angle: An angle in degrees.
             origin: A ladybug_geometry Point3D for the origin around which the
@@ -590,10 +550,6 @@ class Model(_Base):
     def reflect(self, plane):
         """Reflect this Model across a plane with the input normal vector and origin.
 
-        Note that using this method does NOT reflect the model north_vector and,
-        if it is desired that this north_vector be reflected with the model geometry,
-        it must be reflected separately.
-
         Args:
             plane: A ladybug_geometry Plane across which the object will
                 be reflected.
@@ -1107,8 +1063,6 @@ class Model(_Base):
         if self._orphaned_doors != []:
             base['orphaned_doors'] = \
                 [dr.to_dict(True, included_prop) for dr in self._orphaned_doors]
-        if self.north_angle != 0:
-            base['north_angle'] = self.north_angle
         if self.tolerance != 0:
             base['tolerance'] = self.tolerance
         if self.angle_tolerance != 0:
@@ -1201,7 +1155,7 @@ class Model(_Base):
             [shade.duplicate() for shade in self._orphaned_shades],
             [aperture.duplicate() for aperture in self._orphaned_apertures],
             [door.duplicate() for door in self._orphaned_doors],
-            self.north_angle, self.units, self.tolerance, self.angle_tolerance)
+             self.units, self.tolerance, self.angle_tolerance)
         new_model._display_name = self.display_name
         new_model._user_data = None if self.user_data is None else self.user_data.copy()
         new_model._properties._duplicate_extension_attr(self._properties)
